@@ -955,16 +955,30 @@ describe('volume', () => {
         vol.truncateSync('/1', 2);
         expect(vol.readFileSync('/1', 'utf8')).toBe('12');
       });
+      it('Larger truncate', () => {
+        const fd = vol.openSync('/2', 'w');
+        vol.writeFileSync(fd, '12345');
+        expect(vol.readFileSync('/2', 'utf8')).toBe('12345');
+        vol.truncateSync('/2', 10);
+        expect(vol.readFileSync('/2', 'utf8')).toBe('12345\0\0\0\0\0');
+      });
     });
     describe('.truncate(path[, len], callback)', () => {
       xit('...', () => {});
     });
     describe('.utimesSync(path, atime, mtime)', () => {
       const vol = new Volume();
+      vol.mkdirSync('/foo');
       it('Set times on file', () => {
-        vol.writeFileSync('/lol', '12345');
-        vol.utimesSync('/lol', 1234, 12345);
-        const stats = vol.statSync('/lol');
+        vol.writeFileSync('/foo/lol', '12345');
+        vol.utimesSync('/foo/lol', 1234, 12345);
+        const stats = vol.statSync('/foo/lol');
+        expect(Math.round(stats.atime.getTime() / 1000)).toBe(1234);
+        expect(Math.round(stats.mtime.getTime() / 1000)).toBe(12345);
+      });
+      it('Sets times on a directory', () => {
+        vol.utimesSync('/foo', 1234, 12345);
+        const stats = vol.statSync('/foo');
         expect(Math.round(stats.atime.getTime() / 1000)).toBe(1234);
         expect(Math.round(stats.mtime.getTime() / 1000)).toBe(12345);
       });
@@ -994,7 +1008,7 @@ describe('volume', () => {
       });
       it('Create /dir1/dir2/dir3 recursively', () => {
         const vol = new Volume();
-        vol.mkdirSync('/dir1/dir2/dir3', { recursive: true });
+        const fullPath = vol.mkdirSync('/dir1/dir2/dir3', { recursive: true });
         const dir1 = tryGetChild(vol.root, 'dir1');
         const dir2 = tryGetChild(dir1, 'dir2');
         const dir3 = tryGetChild(dir2, 'dir3');
@@ -1004,6 +1018,9 @@ describe('volume', () => {
         expect(dir1.getNode().isDirectory()).toBe(true);
         expect(dir2.getNode().isDirectory()).toBe(true);
         expect(dir3.getNode().isDirectory()).toBe(true);
+        expect(fullPath).toBe('/dir1/dir2/dir3');
+        const dirAlreadyExists = vol.mkdirSync('/dir1/dir2/dir3', { recursive: true });
+        expect(dirAlreadyExists).toBe(undefined);
       });
     });
     describe('.mkdir(path[, mode], callback)', () => {
@@ -1097,6 +1114,24 @@ describe('volume', () => {
         }, 1);
       });
     });
+    describe('.chmodSync(path, mode)', () => {
+      it('works with directories', () => {
+        const vol = new Volume();
+        vol.mkdirSync('/dir');
+        vol.chmodSync('/dir', 0o666);
+        expect(vol.statSync('/dir').mode.toString(8)).toBe('40666');
+        vol.chmodSync('/dir', 0o777);
+        expect(vol.statSync('/dir').mode.toString(8)).toBe('40777');
+      });
+      it('works with files', () => {
+        const vol = new Volume();
+        vol.writeFileSync('/file', 'contents');
+        vol.chmodSync('/file', 0o666);
+        expect(vol.statSync('/file').mode.toString(8)).toBe('100666');
+        vol.chmodSync('/file', 0o777);
+        expect(vol.statSync('/file').mode.toString(8)).toBe('100777');
+      });
+    });
     describe('.promises', () => {
       it('Have a promises property', () => {
         const vol = new Volume();
