@@ -5,7 +5,7 @@ it('should throw error instead of callback', () => {
   const { Volume } = require('../../volume');
   const vol = new Volume();
 
-  vol.writeFile('/asdf.txt', 'asdf', 'utf8', (err) => {
+  vol.writeFile('/asdf.txt', 'asdf', 'utf8', err => {
     if (!err) {
       throw new Error('try to trigger catch');
     }
