@@ -1,6 +1,6 @@
 import { create } from '../util';
 
-describe('.realpath(...)', () => {
+describe('.realpathSync(...)', () => {
   it('works with symlinks, #463', () => {
     const vol = create({});
     vol.mkdirSync('/a');
@@ -11,4 +11,8 @@ describe('.realpath(...)', () => {
     const path = vol.realpathSync('/a/b/index.js');
     expect(path).toBe('/c/index.js');
   });
+  it('returns the root correctly', () => {
+    const vol = create({ './a': 'a' });
+    expect(vol.realpathSync('/')).toBe('/');
+  });
 });
